==> overate-vntech.nestjs.aloline.entity-test-0.1.2.tgz: package/src/redis/key.redis.ts <==
export class RedisKey {
  ACTION_LEVEL: string;
  STICKER_DEFAULT: string;
  STICKER_FIRST_MESSAGE: string;

  private PREFIX: string;

  constructor(env: string) {
    const ENV = env.toUpperCase();

    this.PREFIX = ENV + ':' + 'ALOLINE';

    this.ACTION_LEVEL = this.PREFIX + ':' + 'ACTION_LEVEL';
    this.STICKER_DEFAULT = this.PREFIX + ':' + 'STICKER_DEFAULT';
    this.STICKER_FIRST_MESSAGE = this.PREFIX + ':' + 'STICKER_FIRST_MESSAGE';
  }

  USER_INFO(userId: string, userInfoSubKey: USER_INFO_SUB_KEY) {
    return this.PREFIX + ':' + 'USER_INFO' + ':' + userId + ':' + userInfoSubKey;
  }

  CONVERSATION(conversationId: string, conversationSubKey: CONVERSATION_SUB_KEY) {
    return this.PREFIX + ':' + 'CONVERSATION' + ':' + conversationId + ':' + conversationSubKey;
  }

  CONVERSATION_USER_BACKGROUND(userId: string, conversationId: string) {
    return this.PREFIX + ':' + 'CONVERSATION_USER_BACKGROUND' + ':' + userId + ':' + conversationId;
  }

  CARD_TAG(cardTagId: string) {
    return this.PREFIX + ':' + 'CARD_TAG' + ':' + cardTagId;
  }

  NO_OF_NOT_SEEN(userId: string) {
    return this.PREFIX + ':' + 'NO_OF_NOT_SEEN' + ':' + userId;
  }

  STICKER(categoryStickerId: string) {
    return this.PREFIX + ':' + 'STICKER' + ':' + categoryStickerId;
  }

  STICKER_CATEGORY(categoryStickerId: string) {
    return this.PREFIX + ':' + 'STICKER_CATEGORY' + ':' + categoryStickerId;
  }
}

type USER_INFO_SUB_KEY =
  | 'BLOCK'
  | 'CONNECTION'
  | 'CONVERSATION_HIDDEN'
  | 'CONVERSATION_REMOVE'
  | 'CONVERSATION_DISABLE_NOTIFY'
  | 'CONVERSATION_PINNED'
  | 'FOLLOW'
  | 'FRIEND'
  | 'MY_STICKER'
  | 'NOT_SUGGEST'
  | 'PROFILE'
  | 'WAITING_CONFIRM'
  | 'WAITING_RESPONSE'
  | 'STICKER_RECENTLY'
  | 'UN_FOLLOW'
  | 'HIDDEN_POST';

type CONVERSATION_SUB_KEY = 'LAST_MESSAGE';

==> overate-vntech.nestjs.aloline.entity-test-0.1.5.tgz: package/src/redis/key.redis.ts <==
export class RedisKey {
  ACTION_LEVEL: string;
  STICKER_DEFAULT: string;
  STICKER_FIRST_MESSAGE: string;

  private PREFIX: string;

  constructor(env: string) {
    const ENV = env.toUpperCase();

    this.PREFIX = ENV + ':' + 'ALOLINE';

    this.ACTION_LEVEL = this.PREFIX + ':' + 'ACTION_LEVEL';
    this.STICKER_DEFAULT = this.PREFIX + ':' + 'STICKER_DEFAULT';
    this.STICKER_FIRST_MESSAGE = this.PREFIX + ':' + 'STICKER_FIRST_MESSAGE';
  }

  USER_INFO(userId: string | number, userInfoSubKey: USER_INFO_SUB_KEY) {
    return this.PREFIX + ':' + 'USER_INFO' + ':' + userId + ':' + userInfoSubKey;
  }

  USER_CONNECTION(userId: string | number, device: string) {
    return this.PREFIX + ':' + 'USER_CONNECTION' + ':' + userId + ':' + device;
  }

  CONVERSATION(conversationId: string, conversationSubKey: CONVERSATION_SUB_KEY) {
    return this.PREFIX + ':' + 'CONVERSATION' + ':' + conversationId + ':' + conversationSubKey;
  }

  CONVERSATION_USER_BACKGROUND(userId: string | number, conversationId: string) {
    return this.PREFIX + ':' + 'CONVERSATION_USER_BACKGROUND' + ':' + userId + ':' + conversationId;
  }

  CARD_TAG(cardTagId: string) {
    return this.PREFIX + ':' + 'CARD_TAG' + ':' + cardTagId;
  }

  NO_OF_NOT_SEEN(userId: string | number) {
    return this.PREFIX + ':' + 'NO_OF_NOT_SEEN' + ':' + userId;
  }

  STICKER(categoryStickerId: string) {
    return this.PREFIX + ':' + 'STICKER' + ':' + categoryStickerId;
  }

  STICKER_CATEGORY(categoryStickerId: string) {
    return this.PREFIX + ':' + 'STICKER_CATEGORY' + ':' + categoryStickerId;
  }
}

type USER_INFO_SUB_KEY =
  | 'BLOCK'
  | 'CONVERSATION_HIDDEN'
  | 'CONVERSATION_REMOVE'
  | 'CONVERSATION_DISABLE_NOTIFY'
  | 'CONVERSATION_PINNED'
  | 'FOLLOW'
  | 'FRIEND'
  | 'MY_STICKER'
  | 'NOT_SUGGEST'
  | 'PROFILE'
  | 'WAITING_CONFIRM'
  | 'WAITING_RESPONSE'
  | 'STICKER_RECENTLY'
  | 'UN_FOLLOW'
  | 'HIDDEN_POST'
  | 'LAST_CONNECT';

type CONVERSATION_SUB_KEY = 'LAST_MESSAGE' | 'NOTIFY';
